@@ -19,6 +19,8 @@ from .license import get_license_choices_of_theme, inform_license
 from .version import VERSION_STR
 
 _DEFAULT_WIDTH_CM = 7.0
+_DEFAULT_RESOLUTION_DPI = 90.0
+_DEFAULT_WIDTH_PIXEL = cm_to_pixel(_DEFAULT_WIDTH_CM, _DEFAULT_RESOLUTION_DPI)
 
 _PIECE_SCALE_MIN = 0.0
 _PIECE_SCALE_MAX = 1.2
@@ -59,7 +61,8 @@ def run(options):
         elif is_xay_content(content):
             atoms_to_put = list(iterate_xay_tokens(content))
         elif 'WXF' in content:
-            atoms_to_put = list(iterate_wxf_tokens(content, options.moves_to_play))
+            atoms_to_put = list(
+                iterate_wxf_tokens(content, options.moves_to_play, options.annotate_last_move))
         else:
             atoms_to_put = list(iterate_fen_tokens(content))
 
@@ -174,18 +177,23 @@ def main():
                                dest='width_pixel',
                                metavar='PIXEL',
                                type=float,
-                               help='width of the output in pixels')
+                               help=('width of the output in pixels'
+                                     f' (default: ~{_DEFAULT_WIDTH_PIXEL:.2f},'
+                                     f' i.e. {_DEFAULT_WIDTH_CM}cm'
+                                     f' at {_DEFAULT_RESOLUTION_DPI}dpi)'))
     width_options.add_argument('--width-cm',
                                dest='width_centimeter',
                                metavar='CENTIMETER',
                                type=float,
-                               help='width of the output in centimeters')
+                               help=('width of the output in centimeters'
+                                     f' (default: {_DEFAULT_WIDTH_CM})'))
     scaling_options.add_argument('--dpi',
                                  dest='resolution_dpi',
                                  metavar='FLOAT',
                                  type=float,
-                                 default=90.0,
-                                 help='resolution of the output in dots per inch')
+                                 default=_DEFAULT_RESOLUTION_DPI,
+                                 help=('resolution of the output in dots per inch'
+                                       ' (default: %(default)s)'))
     scaling_options.add_argument(
         '--scale-pieces',
         dest='piece_scale',
@@ -205,24 +213,32 @@ def main():
         f'factor to scale annotations by ({_PIECE_SCALE_MIN:.1f} to {_PIECE_SCALE_MAX:.1f}, default: %(default)s)'
     )
 
+    wxf_options = parser.add_argument_group('WXF format arguments')
+    wxf_options.add_argument('--moves',
+                             default='0',
+                             dest='moves_to_play',
+                             metavar='COUNT',
+                             type=_type_moves_to_play,
+                             help=_format_right_help_column(
+                                 'how many moves to play (for a file with moves history)'
+                                 ', e.g. "3" would play the first move of red,'
+                                 ' the first move of black and the second move of red'
+                                 ' and then skip any remaining moves,'
+                                 f' "{ALL_MOVES}" would play all moves,'
+                                 ' "-1" all moves but the last, "-2" all but the last two'
+                                 ' (default: "%(default)s")'))
+    wxf_options.add_argument('--annotate-last-move',
+                             default=False,
+                             dest='annotate_last_move',
+                             action='store_true',
+                             help=_format_right_help_column(
+                                 'Add annotations "blank_move" and "piece_move"'
+                                 ' to the source and target locations of the last move'))
+
     parser.add_argument('--debug',
                         action='store_true',
                         help='enable debugging (e.g. mark corners of the board)')
 
-    parser.add_argument('--moves',
-                        default='0',
-                        dest='moves_to_play',
-                        metavar='COUNT',
-                        type=_type_moves_to_play,
-                        help=_format_right_help_column(
-                            'how many moves of a game in a WXF file to play'
-                            ', e.g. "3" would play the first move of red,'
-                            ' the first move of black and the second move of red'
-                            ' and then skip any remaining moves,'
-                            f' "{ALL_MOVES}" would play all moves,'
-                            ' "-1" all moves but the last, "-2" all but the last two'
-                            ' (default: "%(default)s")'))
-
     parser.add_argument('input_file',
                         metavar='INPUT_FILE',
                         help='location of WXF/FEN/annoFEN/XAY file to render')
